function loadMap(mapFile)
	-- open our map and layer files
	Map = io.open("./Data/Maps/" .. mapFile .. "/" .. mapFile .. ".map", "r")
	Layer = io.open("./Data/Maps/" .. mapFile .. "/" .. mapFile .. ".lay", "r")

	-- read in the map data: Title,  width, height
	MapTitle = Map:read("*l")
	MapWidth = Map:read("*n")
	MapHeight = Map:read("*n")
		
	-- go to the next line after reading the number
	Map:read("*l")

	-- read the basic map data and layer info into the array
	MapData = {base = {}, layer1 = {}}
	for i=1,tonumber(MapHeight) do
		MapData.base[i] = Map:read("*l")
		MapData.layer1[i] = Layer:read("*l")
	end
		
	-- close the map file
	Map:close()
	Layer:close()
	
	-- open our tileset file
	tileset = io.open("./Data/Maps/" ..  mapFile .. "/" .. mapFile .. ".til", "r")
		
	-- get the image with the tiles and the number of tiles in this set
	tileImageString = tileset:read("*l")
	numTiles = tileset:read("*n")
	
	-- get to the next line
	tileset:read("*l")
	
	-- create the array for the tile data
	tileData = {image, x = {}, y = {}}
	
	-- load the tile image set
	tileData.image = Image.load("./Data/Textures/Tiles/" .. string.sub(tileImageString, 1, string.len(tileImageString) - 1))
	
	-- load the tile data into the array
	for j=1,numTiles do
		tb = tileset:read("*l")
		ctmp1 = string.find(tb,",")
		tileData.x[j] = tonumber(string.sub(tb,ctmp1 + 1))
		tileData.y[j] = tonumber(string.sub(tb,1,ctmp1 - 1))
	end
	
	-- close the tileset
	tileset:close()
		
	-- our starting pixel position
	itx = 0
	ity = 0

	-- our current pixel positions 
	tx = itx
	ty = ity
		
	-- current map x and y position
	cmx = 0
	cmy = 0 
	
	
	-- create our empty texture
	mapbuf = Image.createEmpty(480,512)
		
	-- loop through our tile data
	for i=1,MapHeight do
		-- if this is an odd row, start drawing 32 pixels ahead of our initial position for correct tiling
		if math.mod((i - 1),2) == 0 then
			tx = itx
		else
			tx = itx + 32
		end
		-- loop through this row of tiles
		for j=1,MapWidth do
			-- blit our tile to the static map texture
			mapbuf:blit(tx,ty,tileData.image,tileData.x[numFromString(MapData.base[i],j)],tileData.y[numFromString(MapData.base[i],j)],64,32,true)
			
			-- blit our second layer on top of the first if there is one
			if numFromString(MapData.layer1[i],j) ~= 0 then
				mapbuf:blit(tx,ty,tileData.image,tileData.x[numFromString(MapData.layer1[i],j)],tileData.y[numFromString(MapData.layer1[i],j)],64,32,true)
			end
			-- move 64 pixels to the right for the next tile to start
			tx = tx + 64
		end
		-- move 16 pixels down (half of 32 because of the alternate tiling) for the next row to start
		ty = ty + 16
	end
	return mapFile
end